import { supportsAutomaticCircleBridge, supportsCircleBridge, } from "./protocols/cctp";
import { supportsAutomaticTokenBridge, supportsTokenBridge, } from "./protocols/tokenBridge";
export class ChainContext {
    chain;
    // Cached Protocol clients
    rpc;
    tokenBridge;
    autoTokenBridge;
    circleBridge;
    autoCircleBridge;
    constructor(chain) {
        this.chain = chain;
    }
    getRpc() {
        this.rpc = this.rpc ? this.rpc : this.platform.getRpc(this.chain);
        return this.rpc;
    }
    // Get the number of decimals for a token
    async getDecimals(token) {
        return this.platform.getDecimals(this.chain, this.getRpc(), token);
    }
    // Get the balance of a token for a given address
    async getBalance(walletAddr, token) {
        return this.platform.getBalance(this.chain, this.getRpc(), walletAddr, token);
    }
    async getCurrentBlock() {
        return this.platform.getCurrentBlock(this.getRpc());
    }
    // Get details about the transaction
    async parseTransaction(txid) {
        return this.platform.parseTransaction(this.chain, this.getRpc(), txid);
    }
    // Send a transaction and wait for it to be confirmed
    async sendWait(stxns) {
        return this.platform.sendWait(this.chain, this.getRpc(), stxns);
    }
    //
    // protocols
    //
    //
    supportsTokenBridge = () => supportsTokenBridge(this.platform);
    async getTokenBridge() {
        if (!supportsTokenBridge(this.platform))
            throw new Error("Platform does not support TokenBridge");
        this.tokenBridge = this.tokenBridge
            ? this.tokenBridge
            : await this.platform.getTokenBridge(this.getRpc());
        return this.tokenBridge;
    }
    supportsAutomaticTokenBridge = () => supportsAutomaticTokenBridge(this.platform);
    async getAutomaticTokenBridge() {
        if (!supportsAutomaticTokenBridge(this.platform))
            throw new Error("Platform does not support AutomaticTokenBridge");
        this.autoTokenBridge = this.autoTokenBridge
            ? this.autoTokenBridge
            : await this.platform.getAutomaticTokenBridge(this.getRpc());
        return this.autoTokenBridge;
    }
    //
    supportsCircleBridge = () => supportsCircleBridge(this.platform);
    async getCircleBridge() {
        if (!supportsCircleBridge(this.platform))
            throw new Error("Platform does not support CircleBridge");
        this.circleBridge = this.circleBridge
            ? this.circleBridge
            : await this.platform.getCircleBridge(this.getRpc());
        return this.circleBridge;
    }
    //
    supportsAutomaticCircleBridge = () => supportsAutomaticCircleBridge(this.platform);
    async getAutomaticCircleBridge() {
        if (!supportsAutomaticCircleBridge(this.platform))
            throw new Error("Platform does not support AutomaticCircleBridge");
        this.autoCircleBridge = this.autoCircleBridge
            ? this.autoCircleBridge
            : await this.platform.getAutomaticCircleBridge(this.getRpc());
        return this.autoCircleBridge;
    }
}
//# sourceMappingURL=chain.js.map